# termtris
A Tetris game in character terminal evironment.

## Installation & Run
Uses **pip** to install the package:

`pip3 install termtris`

Runs command **termtris** or **tt** after installed, then enjoy!

## Background
I wrote this game when I was learning **Python** language a few months ago. As a learning practice, it's not about business, but just for fun and to reminisce about the past.

The game package dependent on my another Python package **ltermio**, no other third-party packages required. In fact, the **ltermio** is its by-product.

I also wrote an AI engine **tzero** for the game, with **C++** language and **ctypes** library, but it consumes too much computing power and doesn't run very well, so I termporarily removed this part of code from the package.
